/*
 * ResponsiveMQ     Bringing media queries to Javascript
 * Author           Keith Jackson (tiefling)
 * Company          The Ministry of Technology (ministryotech)
 * License          MIT / http://bit.ly/mit-license
 */
(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function default_1(/** @type {JQueryStatic} */ $) {
        var responsiveMq = {};
        /**
         * @type {*[]}
         */
        responsiveMq.registeredBreakpoints = [];
        responsiveMq.lastActiveBreakpointName = '';
        /**
         * Register a breakpoint.
         * @param {string} name
         * @param {string} mediaQueryCssName
         * @param {Function} matchedFunc
         * @param {Function} notMatchedFunc
         */
        responsiveMq.registerBreakpoint = function (name, mediaQueryCssName, matchedFunc, notMatchedFunc) {
            responsiveMq.registeredBreakpoints.push({
                'name': name,
                'mediaQueryCssName': mediaQueryCssName,
                'matchedFunc': matchedFunc,
                'notMatchedFunc': notMatchedFunc,
            });
        };
        responsiveMq.activate = function () {
            /**
             * @param {string} className
             */
            var renderMarkup = function (className) {
                $(document.body).append('<span class="' + className + '"></span>');
            };
            /**
             * @param {string} className
             * @param {string} mediaQueryCssName
             */
            var renderStyle = function (className, mediaQueryCssName) {
                var styleString = '\n';
                if (mediaQueryCssName !== '') {
                    styleString += mediaQueryCssName + '{\n';
                    for (var bpi = 0; bpi < responsiveMq.registeredBreakpoints.length; bpi++) {
                        if (responsiveMq.registeredBreakpoints[bpi].name !== className)
                            styleString += '   .' + responsiveMq.registeredBreakpoints[bpi].name + ' { display: none; }\n';
                        else
                            styleString += '   .' + className + ' { display: inline; }\n';
                    }
                    styleString += '}\n';
                }
                else {
                    for (var bpx = 0; bpx < responsiveMq.registeredBreakpoints.length; bpx++) {
                        if (responsiveMq.registeredBreakpoints[bpx].name !== className)
                            styleString += '.' + responsiveMq.registeredBreakpoints[bpx].name + ' { display: none; }\n';
                        else
                            styleString += '.' + className + ' { display: inline; }\n';
                    }
                }
                $(document.head).append('<style>' + styleString + '</style>');
            };
            var applyResponsiveJs = function () {
                for (var rjsi = 0; rjsi < responsiveMq.registeredBreakpoints.length; rjsi++) {
                    var bp = responsiveMq.registeredBreakpoints[rjsi];
                    if ($('.' + bp.name).css('display') === 'inline') {
                        if (bp.name !== responsiveMq.lastActiveBreakpointName) {
                            responsiveMq.lastActiveBreakpointName = bp.name;
                            var matchedFunc = bp.matchedFunc;
                            if (matchedFunc !== undefined && matchedFunc !== null)
                                matchedFunc();
                        }
                    }
                    else {
                        var notMatchedFunc = bp.notMatchedFunc;
                        if (notMatchedFunc !== undefined && notMatchedFunc !== null)
                            notMatchedFunc();
                    }
                }
            };
            for (var i = 0; i < responsiveMq.registeredBreakpoints.length; i++) {
                renderMarkup(responsiveMq.registeredBreakpoints[i].name);
                renderStyle(responsiveMq.registeredBreakpoints[i].name, responsiveMq.registeredBreakpoints[i].mediaQueryCssName);
            }
            $(window).on('resize', applyResponsiveJs);
            $(document).ready(applyResponsiveJs);
        };
        return responsiveMq;
    }
    exports.default = default_1;
});
//# sourceMappingURL=responsive-mq.js.map